@@ -62,11 +62,12 @@
 #include <misc.h>
 #include <xf86.h>
 #define NEED_XF86_TYPES
-#include <xf86_ansic.h>
 #include <xf86_OSproc.h>
 #include <xf86Xinput.h>
 #include <xisb.h>
-#include <exevents.h>			/* Needed for InitValuator/Proximity stuff	*/
+#include <exevents.h>	/* Needed for InitValuator/Proximity stuff	*/
+#include <string.h>
+#include <stdio.h>
 
 /*****************************************************************************
  *	Local Headers
@@ -104,7 +105,7 @@ static XF86ModuleVersionInfo VersionRec =
 	MODINFOSTRING1,
 	MODINFOSTRING2,
 	XORG_VERSION_CURRENT,
-	1, 0, 0,
+	1, 1, 0,
 	ABI_CLASS_XINPUT,
 	ABI_XINPUT_VERSION,
 	MOD_CLASS_XINPUT,
